@@ -13,6 +13,7 @@ extern crate serde_derive;
 use wasm_bindgen::prelude::*;
 
 pub mod api;
+pub mod arg_names;
 pub mod char;
 pub mod classes;
 pub mod closures;
@@ -22,11 +23,14 @@ pub mod duplicates;
 pub mod enums;
 #[path = "final.rs"]
 pub mod final_;
+pub mod futures;
+pub mod getters_and_setters;
 pub mod import_class;
 pub mod imports;
 pub mod js_objects;
 pub mod jscast;
 pub mod math;
+pub mod no_shims;
 pub mod node;
 pub mod option;
 pub mod optional_primitives;
@@ -34,6 +38,7 @@ pub mod rethrow;
 pub mod simple;
 pub mod slice;
 pub mod structural;
+pub mod truthy_falsy;
 pub mod u64;
 pub mod validate_prt;
 pub mod variadic;
